@@ -6,14 +6,16 @@ TEST_CASE("bench", "[.]") {
         uint64_t r = 0;
         for (int i = 0; i < 1000; ++i) {
             auto p = malloc(30000000);
-            free(p);
             r += (uint64_t)p;
+            free(p);
         }
         return r;
     };
     BENCHMARK("hello2") {
+        uint64_t ret;
         auto p = malloc(30000000);
+        ret = (uint64_t)p;
         free(p);
-        return p;
+        return ret;
     };
 }
